@@ -46,6 +46,13 @@ class GSPeerConnectionBroadcaster:
     @classmethod
     async def create(cls, gsdbs):
         self = GSPeerConnectionBroadcaster()
+        rtconfiList = []
+        if self.gsdbs.credentials["stunEnable"]:
+            rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
+        if self.gsdbs.credentials["turnenable"]:
+            rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
+                                            self.gsdbs.credentials["turnuser"],
+                                            self.gsdbs.credentials["turnpw"]))
 
         with picamera.PiCamera() as camera:
             self.gsdbs = gsdbs
@@ -86,12 +93,10 @@ class GSPeerConnectionBroadcaster:
 
             @self.sio.event
             async def watcher(id):
-                pc = RTCPeerConnection(configuration=RTCConfiguration([
-                    RTCIceServer("stun:stun.l.google:19302"),
-                    RTCIceServer(self.gsdbs.credentials["turnserver"],
-                                 self.gsdbs.credentials["turnuser"],
-                                 self.gsdbs.credentials["turnpw"]),
-                ]))
+                if len(rtconfiList) > 0:
+                    pc = RTCPeerConnection(configuration=RTCConfiguration(rtconfiList))
+                else:
+                    pc = RTCPeerConnection()
 
                 self.peerConnections[id] = pc
 
